Bifrost: src/UnitigMap.hpp File Reference

Bifrost

Data Structures
UnitigMap.hpp File Reference

UnitigMap type interface. More...

Go to the source code of this file.

## Data Structures
class | Unitig< T >
| Represent a unitig which is a vertex of the Compacted de Bruijn graph. More...
class | CompactedDBG< Unitig_data_t, Graph_data_t >
| Represent a Compacted de Bruijn graph. More...
class | BackwardCDBG< Unitig_data_t, Graph_data_t, is_const >
| Wrapper for class neighborIterator to iterate over the predecessors of a reference unitig used in a UnitigMap object. More...
class | ForwardCDBG< Unitig_data_t, Graph_data_t, is_const >
| Wrapper for class neighborIterator to iterate over the predecessors of a reference unitig used in a UnitigMap object. More...
class | neighborIterator< Unitig_data_t, Graph_data_t, is_const >
| Iterator for the neighbors (predecessors or successors) of a reference unitig used in a UnitigMap object. More...
class | UnitigMapBase
| Structure containing the basic information of a unitig mapping. More...
class | UnitigMap< Unitig_data_t, Graph_data_t, is_const >
| Contain all the information for the mapping of a k-mer or a sequence to a unitig of a Compacted de Bruijn graph. More...
struct | UnitigMapHash< Unitig_data_t, Graph_data_t, is_const >

## Detailed Description

UnitigMap type interface.

Code snippets using this interface are provided in snippets/test.cpp.